==> widestudio-3.70.10_FreeBSD4.9R.tgz: ws/include/WSCj3wform.h <==
//
// Copyright (C) 1999-2004 Toshikaz Hirabayashi
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// TOSHIKAZ HIRABAYASHI BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY,
// WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
// OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of Toshikaz Hirabayashi shall
// not be used in advertising or otherwise to promote the sale, use or other
// dealings in this Software without prior written authorization from
// Toshikaz Hirabayashi.

#ifndef WSCJ3WFORM_H
#define WSCJ3WFORM_H

#include <WScom.h>
#include <WSCform.h>
//#include <j3w/axis.h>
//#include <j3w/hobj3d.h>
//#include <j3w/j3djob.h>
//#include <j3w/j3dproc.h>
//#include <j3w/jrlcode.h>
//#include <j3w/misc3d.h>
//#include <j3w/object3d.h>
//#include <j3w/pal256.h>
//#include <j3w/scrnx.h>
//#include <j3w/spaceh3d.h>
//#include <j3w/tpolygon.h>
//#include <j3w/vertex.h>
#include <WSDprivateTimer.h>

#define WSCj3wform_VER  1000
class TSpaceH3D;
class ScrnX;
class TJob;
class WSCj3wform   :public WSCform{

  protected:
    WSDprivateTimer* _timer;

    char* _fname;
    WSMFpropertyDef(WSNfileName,       char*,     _fname );

    TSpaceH3D* _sp;
    ScrnX* _sc;
    TJob* _job;
   
    virtual long _device_initialize();
    long _j3w_initialize();
static void _timer_proc(void*);

  public:
    WSCj3wform(WSCbase*,char*);
    virtual ~WSCj3wform();

    long loadFile(char*);

    virtual long draw();
    virtual void onVisibleChange(WSCbool);
    virtual void onParentVisibleChange(WSCbool);
    WSMFguiClassDef(WSCj3wform,WSCform);
    WSMFversionDef(WSCj3wform);
};
#endif

==> widestudio-3.80.5_FreeBSD4.10R.tgz: ws/include/WSCj3wform.h <==
//
// Copyright (C) 1999-2004 WideStudio Development Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// WIDESTUDIO DEVELOPMENT TEAM BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
// Except as contained in this notice, the name of WideStudio Development Team
// shall not be used in advertising or otherwise to promote the sale, use or
// other dealings in this Software without prior written authorization from
// WideStudio Development Team.

#ifndef WSCJ3WFORM_H
#define WSCJ3WFORM_H

#include <WScom.h>
#include <WSCform.h>
//#include <j3w/axis.h>
//#include <j3w/hobj3d.h>
//#include <j3w/j3djob.h>
//#include <j3w/j3dproc.h>
//#include <j3w/jrlcode.h>
//#include <j3w/misc3d.h>
//#include <j3w/object3d.h>
//#include <j3w/pal256.h>
//#include <j3w/scrnx.h>
//#include <j3w/spaceh3d.h>
//#include <j3w/tpolygon.h>
//#include <j3w/vertex.h>
#include <WSDprivateTimer.h>

#define WSCj3wform_VER  1000
class TSpaceH3D;
class ScrnX;
class TJob;
class WSCj3wform   :public WSCform{

  protected:
    WSDprivateTimer* _timer;

    char* _fname;
    WSMFpropertyDef(WSNfileName,       char*,     _fname );

    TSpaceH3D* _sp;
    ScrnX* _sc;
    TJob* _job;
   
    WSDLEX32 virtual long _device_initialize();
    WSDLEX32 long _j3w_initialize();
WSDLEX32 static void _timer_proc(void*);

  public:
    WSDLEX32 WSCj3wform(WSCbase*,char*);
    WSDLEX32 virtual ~WSCj3wform();

    WSDLEX32 long loadFile(char*);

    WSDLEX32 virtual long draw();
    WSDLEX32 virtual void onVisibleChange(WSCbool);
    WSDLEX32 virtual void onParentVisibleChange(WSCbool);
    WSMFguiClassDef(WSCj3wform,WSCform);
    WSMFversionDef(WSCj3wform);
};
#endif
